<template>
  <!--
   本页面模板教程：https://ext.dcloud.net.cn/plugin?id=2588
   uni-list 文档：https://ext.dcloud.net.cn/plugin?id=24
   uniCloud 文档：https://uniapp.dcloud.io/uniCloud/README
   unicloud-db 组件文档：https://uniapp.dcloud.io/uniCloud/unicloud-db
   DB Schema 规范：https://uniapp.dcloud.net.cn/uniCloud/schema
   -->
  <view>
    <!-- 刷新页面后的顶部提示框 -->
    <view class="tips" :class="{ 'tips-ani': tipShow }">刷新成功</view>

    <!-- 基于 uni-list 的页面布局 -->
    <uni-list>
      <!-- to 属性携带参数跳转详情页面，当前只为参考 -->
      <uni-list-item direction="column" v-for="item in data" :key="item.id"
                     :to="'detail?id='+item.id+'&daa001='+item.daA001">
        <!-- 通过header插槽定义列表的标题 -->
        <template v-slot:header>
          <view class="uni-title">{{ item.daA001 }}</view>
        </template>
        <!-- 通过body插槽定义列表内容显示 -->
        <template v-slot:body>
          <view class="uni-list-box">
            <view class="uni-content">
              <view class="uni-title-sub uni-ellipsis-2">{{ item.daA003 }}</view>
              <view class="uni-note">{{ item.daA004 + ' ' + item.daA002 }}</view>
              <view class="uni-note" style="color: red">{{ item.daA018 }}</view>
            </view>
          </view>
        </template>
      </uni-list-item>
    </uni-list>
    <!-- 通过 loadMore 组件实现上拉加载效果，如需自定义显示内容，可参考：https://ext.dcloud.net.cn/plugin?id=29 -->
    <!-- <uni-load-more v-if="loading || options.status === 'noMore' " :status="options.status" /> -->
  </view>
</template>

<script>
export default {
  components: {},
  data() {
    return {
      data: [],
      tipShow: false // 是否显示顶部提示框
    };
  },
  onLoad(options) {

    console.log("onLoad:"+options["id"]);
    //页面加载时调用的事件
    this.init();
  },
  methods: {
    init() {
		let deptNo = "ALL";
		if(this.$loginInfo.deptNo){
			deptNo = this.$loginInfo.deptNo;
		}
      //页面加载时调用的事件
      this.$post({url: "/Demo/getData", data: {deptNo: deptNo}}).then(res => {
        this.data = res.data.tbBillList;
      })
    }
  },
  /**
   * 下拉刷新回调函数
   */
  onPullDownRefresh() {
    //重新执行一遍查询
    this.init();
    this.tipShow = true;
    //关闭动画
    uni.stopPullDownRefresh();

    setTimeout(function () {
      this.tipShow = false;
    }, 3000);
  },
  /**
   * 上拉加载回调函数
   */
  onReachBottom() {
    this.init();
  }
};
</script>

<style lang="scss">
@import '@/common/uni-ui.scss';

page {
  display: flex;
  flex-direction: column;
  box-sizing: border-box;
  background-color: #efeff4;
  min-height: 100%;
  height: auto;
}

.tips {
  color: #67c23a;
  font-size: 14px;
  line-height: 40px;
  text-align: center;
  background-color: #f0f9eb;
  height: 0;
  opacity: 0;
  transform: translateY(-100%);
  transition: all 0.3s;
}

.tips-ani {
  transform: translateY(0);
  height: 40px;
  opacity: 1;
}

.content {
  width: 100%;
  display: flex;
}

.list-picture {
  width: 100%;
  height: 145px;
}

.thumb-image {
  width: 100%;
  height: 100%;
}

.ellipsis {
  display: flex;
  overflow: hidden;
}

.uni-ellipsis-1 {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}

.uni-ellipsis-2 {
  overflow: hidden;
  text-overflow: ellipsis;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
</style>